#! /usr/bin/env python

from setuptools import setup

setup(name='shaderdef',
      version='0.5.1',
      description='Transform Python code into GLSL shaders',
      url='https://github.com/nicholasbishop/shaderdef',
      author='Nicholas Bishop',
      author_email='nicholasbishop@gmail.com',
      license='GNU General Public License v3 or later (GPLv3+)',
      packages=['shaderdef'],
      zip_safe=True)
